@@ -442,10 +442,12 @@ void
 yelp_man_parser_free (YelpManParser *parser)
 {
     guint k;
-    if (parser) {
-        for (k=0; k<MAN_FONTS; k++)
-            g_free (parser->font_registers[k]);
-    }
+
+    if (parser == NULL)
+        return;
+
+    for (k=0; k<MAN_FONTS; k++)
+        g_free (parser->font_registers[k]);
     g_string_free (parser->accumulator, TRUE);
     g_free (parser->title_str);
     g_free (parser->section);
@@ -461,7 +463,7 @@ yelp_man_parser_free (YelpManParser *parser)
 static void
 set_font_register (YelpManParser *parser, guint k, const gchar* name)
 {
-    if (k > MAN_FONTS) {
+    if (k >= MAN_FONTS) {
         g_warning ("Tried to set nonexistant font register %u to %s",
                    k, name);
         return;
@@ -474,7 +476,7 @@ static const gchar*
 get_font (const YelpManParser *parser)
 {
     guint k = parser->current_font;
-    if (k > MAN_FONTS ||
+    if (k >= MAN_FONTS ||
         parser->font_registers[k] == NULL) {
 
         g_warning ("Tried to get nonexistant font register %u", k);
@@ -543,7 +545,7 @@ parse_prologue_line (YelpManParser *parser, GError **error)
 static gboolean
 parse_xf (YelpManParser *parser, GError **error)
 {
-    gchar name[10];
+    gchar name[11];
     guint k;
 
     if (SSCANF ("x f%*s %u %10s", 2, &k, name)) {
@@ -918,7 +920,7 @@ append_nbsps (YelpManParser *parser, guint k)
 static gboolean
 parse_C (YelpManParser *parser, GError **error)
 {
-    gchar name[16];
+    gchar name[17];
     gunichar code = 0;
     guint k;
     gint len;
@@ -1191,7 +1193,7 @@ static gchar *
 find_contiguous_whitespace (gchar *text, guint ws_len)
 {
     guint counter = 0;
-    gchar *ws_start;
+    gchar *ws_start = NULL;
     while (*text) {
         if (g_unichar_isspace (g_utf8_get_char (text))) {
             if (!counter) ws_start = text;
